/*
 * Copyright 2004 Berend "Kirk" Wouda
 * 
 * This file is part of WhatDoYouSee'd.
 * 
 * WhatDoYouSee'd is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * WhatDoYouSee'd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with WhatDoYouSee'd; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// The package, one would expect.
package system;

// Import the GUI.
import gui.WDYSFrame;

// Import the event classes.
import java.awt.FileDialog;
import java.awt.event.*;

// Import the encyption and decryption classes.
import WDYSDecrypt.*;
import WDYSEncrypt.*;

// Import the IOException.
import java.io.IOException;

/**
 * This class processes all the user events.
 * 
 * @author Berend "Kirk" Wouda
 * @version 2.10
 * @since 1.00
 */
public class WDYSControl implements ActionListener {
	/**
	 * Constructs a new control class that processes events from the passed GUI.
	 * 
	 * @param gui The GUI this control class works for.
	 */
	public WDYSControl(WDYSFrame gui) {
		// Set the GUI.
		this.gui = gui;
	}
	
	
	/**
	 * Processes an event caused by the GUI.
	 * 
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent event) {
		// A button has been pressed.
		// Retrieve the action command from the event. 
		String command = event.getActionCommand();
		
		// Find out which button was pressed.
		// The Decrypt button.
		     if(command.equals("DECRYPT"))  decrypt(gui.getEncryptedFilename(), gui.getDecryptedFilename());
		// The Encrypt button.
		else if(command.equals("ENCRYPT"))  encrypt(gui.getDecryptedFilename(), gui.getEncryptedFilename());
		// The Input Browse button.
		else if(command.equals("DECRYPTBROWSE"))  setDecryptedFilename();
		// The Output Browse button.
		else if(command.equals("ENCRYPTBROWSE"))  setEncryptedFilename();
		// Any other action.
		else {
			// This is bad.
		}
	}
	
	/**
	 * Decrypts the encrypted file into the decrypted file.
	 * 
	 * @param in The encrypted file.
	 * @param out The decrypted file.
	 */
	protected void decrypt(String in, String out) {
		// Catch errors.
		try {
			// Construct a decrypt control object.
			WDYSDecryptControl control = new WDYSDecryptControl();
	
			// Ask it to decrypt the file.
			control.decrypt(in, out);
			
			// Please the user.
			gui.popup(in + " succesfully decrypted into " + out + ".");
		}
		catch(IOException e) {
			// Alert the user.
			gui.popup("An error occured while trying to read/write the file: " + e.getMessage());
		}
		catch(WDYSDecryptException e) {
			// Alert the user.
			gui.popup("An error occured while decrypting the file: " + e.getMessage());
		}
	}
	
	/**
	 * Encrypts the decrypted file into the encrypted file.
	 * 
	 * @param in The decrypted file.
	 * @param out The encrypted file.
	 */
	protected void encrypt(String in, String out) {
		// Catch errors.
		try {
			// Construct an encrypt control object.
			WDYSEncryptControl control = new WDYSEncryptControl();
	
			// Ask it to encrypt the file.
			control.encrypt(in, out);
			
			// Please the user.
			gui.popup(in + " succesfully encrypted into " + out + ".");
		}
		catch(IOException e) {
			// Alert the user.
			gui.popup("An error occured while trying to read/write the file: " + e.getMessage());
		}
		catch(WDYSEncryptException e) {
			// Alert the user.
			gui.popup("An error occured while encrypting the file: " + e.getMessage());
		}
	}
	
	/**
	 * Asks the user to browse and select the decrypted file. Then, if the encrypted
	 * filename field is empty, fill in an equivalent name with a .txt extension,
	 * select it and focus it.
	 */
	public void setDecryptedFilename() {
		// Retrieve a file from the user.
		String filename = gui.askForFileSelection("Please select a decrypted file...", FileDialog.LOAD);
		
		// Set the decrypted filename to that filename.
		gui.setDecryptedFilename(filename);
		
		// Check if the encrypted filename field is empty and whether a file was
		// selected.
		if(gui.getEncryptedFilename().equals("") && !filename.equals("")) {
			// Set the encrypted filename field to that filename minus it's
			// extension.
			gui.setEncryptedFilename(filename.substring(0, filename.length() - 4));

			// Select the text in the encrypted filename field.
			gui.selectEncryptedFilenameFieldText();
			
			// Focus it.
			gui.setEncryptedFilenameFieldFocus();
		}
		else {
			// Set focus on the decrypted filename field.
			gui.setDecryptedFilenameFieldFocus();
		}
	}
	
	/**
	 * Asks the user to browse and select the encrypted file. Then, if the decrypted
	 * filename field is empty, fill in an equivalent name with a .txt extension,
	 * select it and focus it.
	 */
	public void setEncryptedFilename() {
		// Retrieve a file from the user.
		String filename = gui.askForFileSelection("Please select an encrypted file...", FileDialog.LOAD);
		
		// Set the encrypted filename to that filename.
		gui.setEncryptedFilename(filename);
		
		// Check if the decrypted filename field is empty and whether a file was
		// selected.
		if(gui.getDecryptedFilename().equals("") && !filename.equals("")) {
			// Set the decrypted filename field to that filename with a .txt
			// extension.
			gui.setDecryptedFilename(filename + ".txt");
			
			// Select the text in the decrypted filename field.
			gui.selectDecryptedFilenameFieldText();
			
			// Focus it.
			gui.setDecryptedFilenameFieldFocus();
		}
		else {
			// Set focus on the encrypted filename field.
			gui.setEncryptedFilenameFieldFocus();
		}
	}
	
	
	/**
	 * The GUI that this control class processes events for.  
	 */
	protected WDYSFrame gui;
}